#include <iostream>
#include <fstream>
#include <cstdio>
#include <vector>
#include <algorithm>
#include <cmath>
using namespace std;

const int NUMITER = 200;
const long double eps = 1e-12;

class Object
{
public:
	long double a;
	int ind;
};

bool operator<(const Object &a, const Object &b)
{
	if (a.a - b.a > eps) return true;
	return false;
}

int n, k;
vector<Object> s;
vector<Object> v;

void Load()
{
	scanf("%d", &n);
	int i;
	for (i = 0; i < n; i++)
	{
		Object q;
		double p;
		scanf("%lf", &p);
		q.a = p;
		q.ind = i + 1;
		s.push_back(q);
	}
	scanf("%d", &k);
	for (i = 0; i < k; i++)
	{
		Object q;
		double p;
		scanf("%lf", &p);
		q.a = p;
		q.ind = i + 1;
		v.push_back(q);
	}
}

vector<Object> ts;

long double GetTime(vector<Object> &s, vector<Object> &v)
{
	int i;
	// cerr << "GetTime:\n";
	// cerr << "s: ";
	for (i = 0; i < s.size(); i++)
	{
		// cerr << "(" << s[i].a << " " << s[i].ind << ") ";
	}
	// cerr << "\n";
	// cerr << "v: ";
	for (i = 0; i < v.size(); i++)
	{
		// cerr << "(" << v[i].a << " " << v[i].ind << ") ";
	}
	// cerr << "\n";
	long double ss, sv;
	ss = sv = 0;         	
	long double t = 0;
	for (i = 0; i < s.size(); i++)
	{
		ss += s[i].a;
		if (i < v.size()) sv += v[i].a;
		// cerr << ss << " " << sv << "\n";
		if (ss / sv > t) t = ss / sv;
	}
	// cerr << "GetTime result " << t << "\n";
	return t;
}

void Solve()
{
	sort(s.begin(), s.end());
	sort(v.begin(), v.end());
	long double t = GetTime(s, v);
	long double curt = 0;
	printf("%.9lf\n", (double)t);
	int cpos = 1;
	while (curt - t < -1e-9)
	{
		long double l, r;
		l = curt;
		r = t;
		int i;
		for (i = 0; i < NUMITER; i++)
		{
			ts.clear();
			int j;
			for (j = 0; j < s.size(); j++)
			{
				Object q = s[j];
				if (j < v.size())
				{
					long double tt = s[j].a - v[j].a * ((l + r) / 2.0 - curt);
					if (tt < -eps) tt = 0;
					q.a = tt;           
				}
				ts.push_back(q);
			}
			sort(ts.begin(), ts.end());
			long double rt = GetTime(ts, v) + (l + r) / 2;
			// cerr << "l = " << l << " r = " << r << " rt = " << rt << "\n"; 
			// cerr << "t = " << t << "\n";
			// cerr << fabs(rt - t) << " " << (fabs(rt - t) < eps) << "\n";
			if (rt < t + eps * cpos)
			{
				l = (l + r) / 2;
				// cerr << "left changed!!!\n";
			}
			else 
			{
				r = (l + r) / 2;
				// cerr << "right changed!!!\n";
			}
		}
		cpos++;
		ts.clear();
		int j;
		for (j = 0; j < s.size(); j++)
		{
			Object q = s[j];
			if (j < v.size())
			{
				printf("%.9lf %d %d\n", (double)curt, s[j].ind, v[j].ind);
				long double tt = s[j].a - v[j].a * ((l + r) / 2.0 - curt);
				if (tt < -eps) tt = 0;
				q.a = tt;           
			}
			ts.push_back(q);
		}
		sort(ts.begin(), ts.end());
		s = ts;
		curt = (l + r) / 2;
		// cerr << "ITERATION ENDED###########################################################################\n";
	}
}

int main()
{
	freopen("olymp.in", "rt", stdin);
	freopen("olymp.out", "wt", stdout);
	Load();
	Solve();
	return 0;
}