import java.io.*;
import java.util.*;

public class olymp_ft implements Runnable {

	private static final double EPS = 1e-12;
	private Scanner in;
	private PrintWriter out;
	String fname = "olymp";

	private void myAssert(boolean e, String message) {
		if (!e) {
			throw new Error("Assertion failure!!! " + message);
		}
	}

	class Job implements Comparable<Job>, Cloneable {
		double size;
		int id;
		
		public Job(double size, int id) {
			this.size = size;
			this.id = id;
		}
		
		public int compareTo(Job o) {
			return -Double.compare(size, o.size);
		}
		
		@Override
		public Job clone() {
			return new Job(size, id);
		}
		
	}
	
	class Firm implements Comparable<Firm> {
		double v;
		int id;

		public Firm(double v, int id) {
			this.v = v;
			this.id = id;
		}
		
		public int compareTo(Firm o) {
			return -Double.compare(v, o.v);
		}
	}
	
	class Result {
		double time;
		int[] job2firm;
		
		public Result(double time, int[] job2firm) {
			this.time = time;
			this.job2firm = job2firm;
		}
		
	}
	
	Result calc(Job[] job, Firm[] firm) {
		int n = job.length;
		int k = firm.length;
		Arrays.sort(job);
		Arrays.sort(firm);
		double s1 = 0;
		double s2 = 0;
		double time = Double.NEGATIVE_INFINITY;
		int[] job2firm = new int[n];
		Arrays.fill(job2firm, -1);
		for (int i = 0; i < Math.max(n, k); i++) {
			if (i < n) {
				s1 += job[i].size;
			}
			if (i < k) {
				s2 += firm[i].v;
			}
			if (i < k && i < n) {
				job2firm[job[i].id] = firm[i].id;
			}
			time = Math.max(time, s1 / s2);
		}
		return new Result(time, job2firm);
	}
	
	public void solve() {
		int n = in.nextInt();
		Job[] allJobs = new Job[n];
		Job[] job = new Job[n];
		for (int i = 0; i < n; i++) {
			job[i] = new Job(in.nextDouble(), i);
			allJobs[i] = job[i];
		}
		
		int k = in.nextInt();
		Firm[] allFirms = new Firm[k];
		Firm[] firm = new Firm[k];
		for (int i = 0; i < k; i++) {
			firm[i] = new Firm(in.nextDouble(), i);
			allFirms[i] = firm[i];
		}
		
		Result res = calc(job, firm);
		out.println(res.time);
		int[] job2firm = res.job2firm;
		double curTime = 0;
		for (int i = 0; i < n; i++) {
			if (job2firm[i] == -1) {
				continue;
			}
			out.println(curTime + " " + (i + 1) + " " + (job2firm[i] + 1));
		}
		while (true) {
			double t0 = calc(job, firm).time;
			double l = 0;
			double r = t0;
			for (int it = 0; it < 100; it++) {
				double m = (l + r) / 2;
				Job[] tJob = new Job[n];
				for (int i = 0; i < n; i++) {
					if (job2firm[i] == -1) {
						tJob[i] = new Job(allJobs[i].size, allJobs[i].id);
						continue;
					}
					tJob[i] = new Job(Math.max(0, allJobs[i].size - m * allFirms[job2firm[i]].v), allJobs[i].id);
				}
				double t = calc(tJob, firm).time;
				if (t + m > t0 + EPS) {
					r = m;
				} else {
					l = m;
				}
			}
			if (l < EPS) {
				break;
			}
			for (int i = 0; i < n; i++) {
				if (job2firm[i] == -1) {
					continue;
				}
				allJobs[i].size = Math.max(0, allJobs[i].size - l * allFirms[job2firm[i]].v);
			}
			curTime += l;
			job2firm = calc(job, firm).job2firm;
			for (int i = 0; i < n; i++) {
				if (job2firm[i] == -1) {
					continue;
				}
				out.println(curTime + " " + (i + 1) + " " + (job2firm[i] + 1));
			}
		}
		
	}

	public void run() {
		try {
			solve();
		} catch (Exception e) {
			e.printStackTrace();
			System.exit(1);
		} finally {
			out.close();
		}		
	}

	public olymp_ft() {
		try {
			in = new Scanner(new File(fname + ".in"));
			out = new PrintWriter(new File(fname + ".out"));
		} catch (Exception e) {
			e.printStackTrace();
			System.exit(1);
		}
	}


	public static void main(String[] args) {
		Locale.setDefault(Locale.US);
		new Thread(new olymp_ft()).start();
	}

}                       