import java.io.*;
import java.util.*;

public class olymp_md implements Runnable {
	private Scanner in;
	private PrintWriter out;
	
	int n, k;
	Obj[] obj;
	int[] cpow;
	ArrayList<Power> powers = new ArrayList<Power>();
	
	double clock = 0;
	double answer = 0;
	PriorityQueue<Event> events = new PriorityQueue<Event>();
	List<Assignment> assignments = new ArrayList<Assignment>();

	private void solve() {
		n = in.nextInt();
		obj = new Obj[n];
		for (int i = 0; i < n; i++) {
			obj[i] = new Obj(in.nextInt(), i);
		}
		Arrays.sort(obj);
		
		k = in.nextInt();
		for (int i = 0; i < k; i++) {
			powers.add(new Power(in.nextInt(), i));
		}
		while (powers.size() < n) {
			powers.add(new Power(0, -1));
		}
		Collections.sort(powers);
		
		cpow = new int[n + 1];
		for (int i = 0; i < n; i++) {
			cpow[i + 1] = cpow[i] + powers.get(i).power;
		}
		
		Task[] init = new Task[n];
		for (int i = 0; i < n; i++) {
			init[i] = new Task(1, obj[i].size, 0, i, i + 1);
		}
		for (int i = 0; i < n; i++) {
			init[i].left = (i > 0) ? init[i - 1] : null;
			init[i].right = (i < n - 1) ? init[i + 1] : null;
		}
		for (int i = 0; i < n; i++) {
			init[i].makeEventDone();
			init[i].makeEventMerge();
		}
		
		while (!events.isEmpty()) {
			Event e = events.poll();
			clock = e.time;
			e.process();
		}
		out.println(answer);
		Collections.sort(assignments);
		for (Assignment a : assignments) {
			out.println(a);
		}
	}
	
	private void addEvent(Event e) {
		events.add(e);
	}
	
	class Obj implements Comparable<Obj> {
		int size;
		int id;
		
		public Obj(int size, int id) {
			this.size = size;
			this.id = id;
		}

		public int compareTo(Obj that) {
			return that.size - size;
		}
	}
	
	class Power implements Comparable<Power> {
		int power;
		int id;
		
		public Power(int power, int id) {
			this.power = power;
			this.id = id;
		}

		public int compareTo(Power that) {
			return that.power - power;
		}
	}
	
	class Task {
		int num;
		double len, time, time0;
		int power;
		int lo, hi;
		Task left, right;
		double timeDone, timeMerge;
		boolean dead;
		
		public Task(int num, double len, double time, int lo, int hi) {
			this.num = num;
			this.len = len;
			this.time = this.time0 = time;
			this.power = cpow[hi] - cpow[lo];
			this.lo = lo;
			this.hi = hi;
			dead = false;
		}
		
		public void update() {
			if (time == clock)
				return;
			len -= (clock - time) * power / num;
			time = clock;
		}
		
		public void makeEventDone() {
			timeDone = time + num * len / power;
			addEvent(new Event(timeDone, this));
		}
		
		public void makeEventMerge() {
			if (right == null)
				return;
			update();
			right.update();
//			if (len < right.len)
//				throw new RuntimeException("wrong order of logs");
			timeMerge = clock + (len - right.len) / (power * 1d / num - right.power * 1d / right.num);
			addEvent(new Event(timeMerge, this, right));
		}

		public void finish() {
			dead = true;
			for (int i = 0; i < num; i++) {
				double time = time0 + (clock - time0) * i / num;
				for (int j = 0; j < num; j++) {
					if (powers.get(lo + j).id >= 0) {
						new Assignment(time, obj[lo + (i + j) % num].id, powers.get(lo + j).id);
					}
				}
			}
			answer = clock;
		}
	}
	
	class Event implements Comparable<Event> {
		double time;
		int type;
		Task task, right;
		
		static final int DONE = 0;
		static final int MERGE = 1;

		public Event(double time, Task task) {
			this.time = time;
			this.type = DONE;
			this.task = task;
		}

		public Event(double time, Task left, Task right) {
			this.time = time;
			this.type = MERGE;
			this.task = left;
			this.right = right;
		}

		public int compareTo(Event that) {
			return Double.compare(time, that.time);
		}

		public void process() {
			if (this.type == DONE) {
				if (task.dead)
					return;
				if (task.left != null) {
					task.left.right = task.right;
				}
				if (task.right != null) {
					task.right.left = task.left;
				}
				task.finish();
				return;
			}
			if (task.dead || right.dead)
				return;
			task.update();
			Task both = new Task(task.num + right.num, task.len, clock, task.lo, right.hi);
			both.left = task.left;
			if (both.left != null) {
				both.left.right = both;
			}
			both.right = right.right;
			if (both.right != null) {
				both.right.left = both;
			}
			task.finish();
			right.finish();
			both.makeEventDone();
			both.makeEventMerge();
			if (both.left != null) {
				both.left.makeEventMerge();
			}
		}
	}
	
	class Assignment implements Comparable<Assignment> {
		double time;
		int objId, powerId;
		
		public Assignment(double time, int objId, int powerId) {
			this.time = time;
			this.objId = objId;
			this.powerId = powerId;
			assignments.add(this);
		}

		public int compareTo(Assignment that) {
			return Double.compare(time, that.time);
		}
		
		public String toString() {
			return time + " " + (objId + 1) + " " + (powerId + 1);
		}
	}
	
	public static void main(String[] args) throws IOException {
		Locale.setDefault(Locale.US);
		new Thread(new olymp_md()).start();
	}

	public void run() {
		try {
			in = new Scanner(new FileReader("olymp.in"));
			out = new PrintWriter("olymp.out");
			solve();
			in.close();
			out.close();
		} catch (FileNotFoundException e) {
			e.printStackTrace();
			System.exit(1);
		}
	}
}
